==> spip_3.0.18.orig.tar.xz: spip/plugins-dist/urls_etendues/lang/urls_ru.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/urls?lang_cible=ru
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'actualiser_toutes' => 'Обновить все URL',
	'actualiser_toutes_explication' => 'Вы можете перегенерировать URLы.
		Если URL был изменен, то будет создан новый (предыдущий URL сохранится, а ссылки, заданные вручную, не изменятся).', # MODIF

	// B
	'bouton_supprimer_url' => 'Удалить URL',

	// E
	'erreur_arbo_2_segments_max' => 'Нельзя использовать более 2 URL для одного объекта',
	'erreur_config_url_forcee' => 'Настройки формата URL хранятся в файле <tt>mes_options.php</tt>.',
	'explication_editer' => 'Расширенные настройки позволяют редактировать URL всех материалов сайта, а так же отслеживать историю их изменений.',

	// I
	'icone_configurer_urls' => 'Настройки URL страниц',
	'icone_controler_urls' => 'Понятные URL',
	'info_1_url' => '1 URL',
	'info_id_parent' => '#родитель (#parent)',
	'info_nb_urls' => '@nb@ URL',
	'info_objet' => 'Объект',

	// L
	'label_tri_date' => 'Дата',
	'label_tri_id' => 'Номер',
	'label_tri_url' => 'URL',
	'label_url' => 'Новый URL',
	'label_url_minuscules_0' => 'Сохранять регистр букв',
	'label_url_minuscules_1' => 'Выводить URL  в нижнем регистре',
	'label_url_permanente' => 'Запретить изменения URL ( ссылка не меняется после изменения материала)',
	'label_url_sep_id' => 'Разделитель между дополнительными цифрами, который добавляются, что бы избежать дублирования URL',
	'label_urls_activer_controle_oui' => 'Расширенные настройки генерации URL',
	'label_urls_nb_max_car' => 'Максимальное количество символов',
	'label_urls_nb_min_car' => 'Минимальное количество символов',
	'liberer_url' => 'Очистить',
	'liste_des_urls' => 'Все URL',

	// T
	'texte_type_urls' => 'Способ формирования URL',
	'texte_type_urls_attention' => 'Внимание, эти настройки будут работать только если файл @htaccess@ из дистрибутива SPIP установлен в корне сайта.',
	'texte_urls_nb_max_car' => 'Длинные названия будут обрезаны автоматически.',
	'texte_urls_nb_min_car' => 'Короткие названия будут дополнены автоматически.',
	'titre_gestion_des_urls' => 'Управление ссылками (URL)',
	'titre_type_arbo' => 'Древовидные ссылки (URLs Arborescentes)',
	'titre_type_html' => 'Ссылки c объектами HTML',
	'titre_type_libres' => 'Свободный формат URLs',
	'titre_type_page' => 'Адрес страницы (URLs Page)',
	'titre_type_propres' => 'Чистые  названия (clean URLs )',
	'titre_type_propres2' => 'Чистые ссылки+<tt>.html</tt>',
	'titre_type_propres_qs' => 'Чистые ссылки в строке запроса',
	'titre_type_simple' => 'Упрощенный формат URL',
	'titre_type_standard' => 'Исторический формат URL',
	'titre_type_urls' => 'Автоматическое формирование URL',
	'tout_voir' => 'Показать все URL',

	// U
	'url_ajout_impossible' => 'Невозможно сохранить URL из-за технической ошибки.',
	'url_ajoutee' => 'URL добавлен',

	// V
	'verifier_url_nettoyee' => 'URL был изменен, проверьте правильность перед сохранением.',
	'verrouiller_url' => 'Заблокировать'
);

?>

==> spip_3.1.3.orig.tar.xz: spip/plugins-dist/urls_etendues/lang/urls_ru.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/urls?lang_cible=ru
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'actualiser_toutes' => 'Обновить все URL',
	'actualiser_toutes_explication' => 'Вы можете переписать URLы.
		Если URL был изменен, то будет создан новый (предыдущий URL сохранится, а ссылки, заданные вручную, не изменятся).',

	// B
	'bouton_supprimer_url' => 'Удалить URL',

	// E
	'erreur_arbo_2_segments_max' => 'Нельзя использовать более 2 URL для одного объекта',
	'erreur_config_url_forcee' => 'Настройки формата URL хранятся в файле <tt>mes_options.php</tt>.',
	'explication_editer' => 'Расширенные настройки позволяют редактировать URL всех материалов сайта, а также отслеживать историю их изменений.',

	// I
	'icone_configurer_urls' => 'Настройки URL страниц',
	'icone_controler_urls' => 'Понятные URL',
	'info_1_url' => '1 URL',
	'info_id_parent' => '#родитель (#parent)',
	'info_nb_urls' => '@nb@ URL',
	'info_objet' => 'Объект',

	// L
	'label_tri_date' => 'Дата',
	'label_tri_id' => 'Номер',
	'label_tri_url' => 'URL',
	'label_url' => 'Новый URL',
	'label_url_minuscules_0' => 'Сохранять регистр букв',
	'label_url_minuscules_1' => 'Выводить URL  в нижнем регистре',
	'label_url_permanente' => 'Запретить изменения URL (ссылка не меняется после изменения материала)',
	'label_url_sep_id' => 'Разделитель между цифрами, которые добавляются, чтобы избежать дублирования URL',
	'label_urls_activer_controle_oui' => 'Расширенные настройки генерации URL',
	'label_urls_nb_max_car' => 'Максимальное количество символов',
	'label_urls_nb_min_car' => 'Минимальное количество символов',
	'liberer_url' => 'Очистить',
	'liste_des_urls' => 'Все URL',

	// T
	'texte_type_urls' => 'Способ формирования URL',
	'texte_type_urls_attention' => 'Внимание, эти настройки будут работать только если файл @htaccess@ из дистрибутива SPIP установлен в корне сайта.',
	'texte_urls_nb_max_car' => 'Длинные названия будут обрезаны автоматически.',
	'texte_urls_nb_min_car' => 'Короткие названия будут дополнены автоматически.',
	'titre_gestion_des_urls' => 'Управление ссылками (URL)',
	'titre_type_arbo' => 'Древовидные ссылки (URLs Arborescentes)',
	'titre_type_html' => 'Ссылки c объектами HTML',
	'titre_type_libres' => 'Свободный формат URLs',
	'titre_type_page' => 'Адрес страницы (URLs Page)',
	'titre_type_propres' => 'Чистые  названия (clean URLs )',
	'titre_type_propres2' => 'Чистые ссылки+<tt>.html</tt>',
	'titre_type_propres_qs' => 'Чистые ссылки в строке запроса',
	'titre_type_simple' => 'Упрощенный формат URL',
	'titre_type_standard' => 'Исторический формат URL',
	'titre_type_urls' => 'Автоматическое формирование URL',
	'tout_voir' => 'Показать все URL',

	// U
	'url_ajout_impossible' => 'Невозможно сохранить URL из-за технической ошибки.',
	'url_ajoutee' => 'URL добавлен',

	// V
	'verifier_url_nettoyee' => 'URL был изменен, проверьте правильность перед сохранением.',
	'verrouiller_url' => 'Заблокировать'
);

?>
